@@ -183,6 +183,7 @@ class SecureFlaskApp(Flask):
         self.url_map.strict_slashes = False
         self.config["JSONIFY_PRETTYPRINT_REGULAR"] = True
         self.secret_key = str(uuid1())
+        self.config["SECRET_KEY"] = self.secret_key
         self.config["TEMPLATES_AUTO_RELOAD"] = True
         self.jinja_env.auto_reload = True
 
@@ -276,8 +277,7 @@ class SecureFlaskApp(Flask):
                     session["cas-after-login"] = f"{request.path}{_parse_query_string(quoted=False)}"
                     response = _login(self.__cas_server_url)
                 else:
-                    raw_cas = session.get("cas-object")
-                    cas = CasUser(raw_cas["user"], raw_cas["attributes"], db_session=self.db, user_table=self.users)
+                    cas = CasUser(current_object["user"], current_object["attributes"], db_session=self.db, user_table=self.users)
 
                     # do role-based security, if it was configured
                     if self.__role_security_configured:
